==> hypixel.py-0.1.3.tar.gz: hypixel.py-0.1.3/hypixel/models/playerdata/tkr.py <==
"""
The MIT License (MIT)

Copyright (c) 2021-present duhby

Permission is hereby granted, free of charge, to any person obtaining a
copy of this software and associated documentation files (the "Software"),
to deal in the Software without restriction, including without limitation
the rights to use, copy, modify, merge, publish, distribute, sublicense,
and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
DEALINGS IN THE SOFTWARE.
"""

from dataclasses import dataclass
from ... import utils

@dataclass
class TurboKartRacers:
    coins: int = 0
    laps: int = 0
    gold: int = 0
    silver: int = 0
    bronze: int = 0
    blue_torpedo_hits: int = 0
    banana_hits: int = 0
    bananas_received: int = 0
    wins: int = 0 # top 3

    @property
    def br(self) -> float:
        return utils.safe_div(self.banana_hits, self.bananas_received)

==> hypixel.py-0.2.1.tar.gz: hypixel.py-0.2.1/hypixel/models/playerdata/tkr.py <==
"""
The MIT License

Copyright (c) 2021-present duhby

Permission is hereby granted, free of charge, to any person obtaining a
copy of this software and associated documentation files (the "Software"),
to deal in the Software without restriction, including without limitation
the rights to use, copy, modify, merge, publish, distribute, sublicense,
and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
DEALINGS IN THE SOFTWARE.
"""

from dataclasses import dataclass
from ... import utils

@dataclass
class TurboKartRacers:
    coins: int = 0
    laps: int = 0
    gold: int = 0
    silver: int = 0
    bronze: int = 0
    blue_torpedo_hits: int = 0
    banana_hits: int = 0
    bananas_received: int = 0
    wins: int = 0 # top 3
    # Handled later
    br: float = None

    def __post_init__(self):
        self.br = utils.safe_div(self.banana_hits, self.bananas_received)
